@@ -15,9 +15,9 @@ from asn1crypto.core import OctetString
 from asn1crypto.algos import SignedDigestAlgorithm, SignedDigestAlgorithmId
 
 from .pkcs11_handle import PKCS11Session
+from .error import DuplicateExtensionException
+
 
-# FIXME allow optional company name when generating csr with openssl
-# THAT IS NOT TESTED
 def _request_to_tbs_certificate(csr_pem: str
                                 ) -> asn1_x509.TbsCertificate:
 
@@ -30,36 +30,42 @@ def _request_to_tbs_certificate(csr_pem: str
     exts = asn1_x509.Extensions()
 
     attrs = req["certification_request_info"]["attributes"]
-    for attr, _ in enumerate(attrs):
-        for extensions, _ in enumerate(attrs[attr]["values"]):
-            for extension, _ in enumerate(attrs[attr]["values"][extensions]):
-                exts.append(attrs[attr]["values"][extensions][extension])
+    for _, attr in enumerate(attrs):
+        for _, extensions in enumerate(attr["values"]):
+            for _, extension in enumerate(extensions):
+                exts.append(extension)
 
     tbs = asn1_x509.TbsCertificate()
     tbs["subject"] = req["certification_request_info"]["subject"]
-    tbs["subject_public_key_info"] = req["certification_request_info"]["subject_pk_info"]
+    tbs["subject_public_key_info"] \
+        = req["certification_request_info"]["subject_pk_info"]
 
     tbs["extensions"] = exts
     return tbs
 
-# Keep only the first one
-# FIXME not tested
-def _set_tbs_remove_duplicate_extensions(tbs: asn1_x509.TbsCertificate
-                                         ) -> asn1_x509.TbsCertificate:
 
-    if len(tbs["extensions"]) == 0:
-        return tbs
+def _check_tbs_duplicate_extensions(tbs: asn1_x509.TbsCertificate
+                                    ) -> None:
+    """
+    A certificate MUST NOT include more
+    than one instance of a particular extension. For example, a
+    certificate may contain only one authority key identifier extension
+    https://www.rfc-editor.org/rfc/rfc5280#section-4.2
 
-    extensions = []
-    exts = asn1_x509.Extensions()
+    Parameters:
+    tbs (asn1_x509.TbsCertificate): The 'To be signed' certificate
 
-    for ext, _ in enumerate(tbs["extensions"]):
-        if tbs["extensions"][ext]["extn_id"].dotted not in extensions:
-            exts.append(tbs["extensions"][ext])
-            extensions.append(tbs["extensions"][ext]["extn_id"].dotted)
+    Returns:
+    None
+    """
+
+    exts = []
+    for _, ext in enumerate(tbs["extensions"]):
+        if ext["extn_id"].dotted in exts:
+            raise DuplicateExtensionException("Found duplicate extension "
+                                              + ext["extn_id"].dotted)
+        exts.append(ext["extn_id"].dotted)
 
-    tbs["extensions"] = exts
-    return tbs
 
 def _set_tbs_issuer(tbs: asn1_x509.TbsCertificate,
                     issuer_name: dict[str, str]
@@ -68,12 +74,14 @@ def _set_tbs_issuer(tbs: asn1_x509.TbsCertificate,
     tbs["issuer"] = asn1_csr.Name().build(issuer_name)
     return tbs
 
+
 def _set_tbs_version(tbs: asn1_x509.TbsCertificate
                      ) -> asn1_x509.TbsCertificate:
 
     tbs["version"] = 2
     return tbs
 
+
 def _set_tbs_serial(tbs: asn1_x509.TbsCertificate
                     ) -> asn1_x509.TbsCertificate:
 
@@ -81,6 +89,7 @@ def _set_tbs_serial(tbs: asn1_x509.TbsCertificate
     tbs["serial_number"] = int.from_bytes(os.urandom(20), "big") >> 1
     return tbs
 
+
 def _set_tbs_validity(tbs: asn1_x509.TbsCertificate
                       ) -> asn1_x509.TbsCertificate:
 
@@ -92,10 +101,11 @@ def _set_tbs_validity(tbs: asn1_x509.TbsCertificate
     val["not_after"] = asn1_x509.Time(name="utc_time",
                                       value=datetime.datetime.now(
                                           datetime.timezone.utc)
-                                      + datetime.timedelta(365,0,0))
+                                      + datetime.timedelta(365, 0, 0))
     tbs["validity"] = val
     return tbs
 
+
 def _set_tbs_ski(tbs: asn1_x509.TbsCertificate
                  ) -> asn1_x509.TbsCertificate:
 
@@ -119,6 +129,7 @@ def _set_tbs_ski(tbs: asn1_x509.TbsCertificate
         tbs["extensions"].append(ext)
     return tbs
 
+
 def _set_tbs_aki(tbs: asn1_x509.TbsCertificate,
                  identifier: bytes
                  ) -> asn1_x509.TbsCertificate:
@@ -126,9 +137,9 @@ def _set_tbs_aki(tbs: asn1_x509.TbsCertificate,
     aki = asn1_x509.AuthorityKeyIdentifier()
     aki["key_identifier"] = identifier
 
-    for extension, _ in enumerate(tbs["extensions"]):
-        if tbs["extensions"][extension]["extn_id"].dotted == "2.5.29.35":
-            tbs["extensions"][extension]["extn_value"] = aki
+    for _, extension in enumerate(tbs["extensions"]):
+        if extension["extn_id"].dotted == "2.5.29.35":
+            extension["extn_value"] = aki
             return tbs
 
     ext = asn1_x509.Extension()
@@ -143,6 +154,7 @@ def _set_tbs_aki(tbs: asn1_x509.TbsCertificate,
         tbs["extensions"].append(ext)
     return tbs
 
+
 def _set_tbs_signature(tbs: asn1_x509.TbsCertificate
                        ) -> asn1_x509.TbsCertificate:
 
@@ -151,12 +163,13 @@ def _set_tbs_signature(tbs: asn1_x509.TbsCertificate
     tbs["signature"] = sda
     return tbs
 
+
 def _create_tbs_certificate(tbs: asn1_x509.TbsCertificate,
                             issuer_name: dict[str, str],
                             aki: bytes
                             ) -> asn1_x509.TbsCertificate:
 
-    tbs = _set_tbs_remove_duplicate_extensions(tbs) # FIXME not tested
+    _check_tbs_duplicate_extensions(tbs)
 
     tbs = _set_tbs_version(tbs)
     tbs = _set_tbs_issuer(tbs, issuer_name)
@@ -167,6 +180,7 @@ def _create_tbs_certificate(tbs: asn1_x509.TbsCertificate,
     tbs = _set_tbs_signature(tbs)
     return tbs
 
+
 def sign_csr(key_label: str,
              issuer_name: dict[str, str],
              csr_pem: str
@@ -193,15 +207,12 @@ def sign_csr(key_label: str,
     signed_cert = asn1_x509.Certificate()
     signed_cert["tbs_certificate"] = tbs
     signed_cert["signature_algorithm"] = tbs["signature"]
-    signed_cert["signature_value"] = PKCS11Session().sign(tbs.dump(), key_label)
+    signed_cert["signature_value"] = PKCS11Session(
+    ).sign(tbs.dump(), key_label)
+
     pem_enc = asn1_pem.armor('CERTIFICATE', signed_cert.dump())
 
     # Needed for mypy strict
     assert isinstance(pem_enc, bytes)
 
-    cert_pem = pem_enc.decode('utf-8')
-
-    # Needed for mypy strict
-    assert isinstance(cert_pem, str)
-
-    return cert_pem
+    return pem_enc.decode('utf-8')
